package   # CPAN, don't index
    Devel::NullDB;

use base 'Devel::Chitin';

1;
